#
# spec file for package python-asyncclick
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define archiveversion 8.1.7.0-async
Name:           python-asyncclick
Version:        8.1.7.0+async
Release:        1.6
Summary:        A wrapper around optparse for command line utilities
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/python-trio/asyncclick
# Upstream forgot to release on PyPI: https://github.com/python-trio/asyncclick/issues/18
#Source:         https://files.pythonhosted.org/packages/source/a/asyncclick/asyncclick-%%{version}.tar.gz
Source:         https://github.com/python-trio/asyncclick/archive/refs/tags/%{version}.tar.gz#/asyncclick-%{archiveversion}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-anyio
# SECTION test
BuildRequires:  %{python_module anyio}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module trio}
# /SECTION
BuildArch:      noarch
%python_subpackages

%description
AsyncClick ist a fork of Click that works well with trio or asyncio.

Click is a Python package for creating command line interfaces
in a composable way with as little code as necessary.  It's the "Command
Line Interface Creation Kit". It is configurable, and comes with
defaults out of the box.

%prep
%setup -q -n asyncclick-%{archiveversion}

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest -rsfE

%files %{python_files}
%license LICENSE.rst
%doc CHANGES.rst README.rst
%{python_sitelib}/asyncclick
%{python_sitelib}/asyncclick-%{version}.dist-info/

%changelog
* Sun Jan 14 2024 Ben Greiner <code@bnavigator.de>
- Update to 8.1.7.0+async
  * Fix issue with regex flags in shell completion. #2581
  * Bash version detection issues a warning instead of an error.
    [#2574]
  * Fix issue with completion script for Fish shell. #2567
- Version 8.1.6
  * Fix an issue with type hints for @click.group(). #2558
  - Version 8.1.5
  * Fix an issue with type hints for @click.command(),
    @click.option(), and other decorators. Introduce typing tests.
    [#2558]
- Version 8.1.4
  * Replace all typing.Dict occurrences to typing.MutableMapping
    for parameter hints. #2255
  * Improve type hinting for decorators and give all generic types
    parameters. #2398
  * Fix return value and type signature of
    shell_completion.add_completion_class function. #2421
  * Bash version detection doesn’t fail on Windows. #2461
  * Completion works if there is a dot (.) in the program name.
    [#2166]
  * Improve type annotations for pyright type checker. #2268
  * Improve responsiveness of click.clear(). #2284
  * Improve command name detection when using Shiv or PEX. #2332
  * Avoid showing empty lines if command help text is empty. #2368
  * ZSH completion script works when loaded from fpath. #2344.
  * EOFError and KeyboardInterrupt tracebacks are not suppressed
    when standalone_mode is disabled. #2380
  * @group.command does not fail if the group was created with a
    custom command_class. #2416
  * multiple=True is allowed for flag options again and does not
    require setting default=(). #2246, #2292, #2295
  * Make the decorators returned by @argument() and @option()
    reusable when the cls parameter is used. #2294
  * Don’t fail when writing filenames to streams with strict
    errors. Replace invalid bytes with the replacement character
    (�). #2395
  * Remove unnecessary attempt to detect MSYS2 environment. #2355
  * Remove outdated and unnecessary detection of App Engine
    environment. #2554
  * echo() does not fail when no streams are attached, such as with
    pythonw on Windows. #2415
  * Argument with expose_value=False do not cause completion to
    fail. #2336
- Switch to github archive, because upstream forgot to release on
  PyPI gh#python-trio/asyncclick#18
* Fri May 19 2023 Dirk Müller <dmueller@suse.com>
- build with setuptools_scm
- build for PSP on sle15
* Thu Oct 27 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 8.1.3.4
  * Use verbose form of typing.Callable for @command and @group. :issue:`2255`
  * Show error when attempting to create an option with multiple=True, is_flag=True. Use count instead. :issue:`2246`
* Thu Sep 29 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Initial version 8.1.3.2
